@@ -12,10 +12,10 @@
 from .commons import (FinishCommand as BaseFinishCommand, GitCommand,
         ReviewCommand as BaseReviewCommand, StartCommand as BaseStartCommand,
         TasksCommand as BaseTasksCommand)
-from .utils import cached_property, prompt
+from .utils import less, prompt
 from clint.textui import colored, puts
-from continuity.pt import PivotalTracker, Story
-from pydoc import pipepager
+from continuity.services.pt import PivotalTrackerService, Story
+from continuity.services.utils import cached_property
 from StringIO import StringIO
 from sys import exit
 
@@ -24,6 +24,20 @@ class PivotalTrackerCommand(GitCommand):
     """Base Pivotal Tracker command.
     """
 
+    @cached_property
+    def owner(self):
+        """Owner accessor.
+        """
+        ret_val = None
+        owner_id = int(self.get_value("pivotal", "owner-id"))
+
+        for member in self.project.members:
+            if owner_id == member.id:
+                ret_val = member
+                break
+
+        return ret_val
+
     @cached_property
     def project(self):
         """Project accessor.
@@ -38,7 +52,7 @@ class PivotalTrackerCommand(GitCommand):
         """
         token = self.get_value("pivotal", "api-token")
 
-        return PivotalTracker(token)
+        return PivotalTrackerService(token)
 
     @cached_property
     def story(self):
@@ -80,14 +94,13 @@ class BacklogCommand(PivotalTrackerCommand):
     def execute(self):
         """Execute this backlog command.
         """
-        owner = self.get_value("pivotal", "owner")
         stories = self.pt.get_backlog(self.project)
         output = StringIO()
 
         for story in stories:
             if story.state in [Story.STATE_UNSCHEDULED,
                     Story.STATE_UNSTARTED] and (self.namespace.mywork is False
-                            or story.owner == owner):
+                            or self.owner in story.owners):
                 id = colored.yellow(str(story.id))
 
                 if story.estimate is None:
@@ -100,17 +113,19 @@ class BacklogCommand(PivotalTrackerCommand):
 
                 name = story.name
 
-                if story.owner:
+                if story.owners:
+                    initials = []
+
                     for member in self.project.members:
-                        if member.name == story.owner:
-                            name = "{0} ({1})".format(story.name,
-                                    member.initials)
-                            break
+                        if member in story.owners:
+                            initials.append(member.initials)
+
+                    name = "{0} ({1})".format(story.name, ', '.join(initials))
 
                 message = "{0} {1}: {2}\n".format(id, type, name)
                 output.write(message)
 
-        pipepager(output.getvalue(), cmd="less -FRSX")
+        less(output)
 
 
 class FinishCommand(BaseFinishCommand, PivotalTrackerCommand):
@@ -135,7 +150,12 @@ class FinishCommand(BaseFinishCommand, PivotalTrackerCommand):
     def finalize(self):
         """Finalize this finish command.
         """
-        self.pt.set_story(self.project, self.story, Story.STATE_FINISHED)
+        if self.story.type == Story.TYPE_CHORE:
+            state = Story.STATE_ACCEPTED
+        else:
+            state = Story.STATE_FINISHED
+
+        self.pt.set_story(self.project, self.story, state)
         puts("Finished story #{0:d}.".format(self.story.id))
         super(FinishCommand, self).finalize()
 
@@ -160,6 +180,102 @@ class ReviewCommand(BaseReviewCommand, PivotalTrackerCommand):
         return self.github.create_pull_request(title, description, branch)
 
 
+class StartCommand(BaseStartCommand, PivotalTrackerCommand):
+    """Start a branch linked to a story.
+
+    :param parser: Command-line argument parser.
+    :param namespace: Command-line argument namespace.
+    """
+
+    def __init__(self, parser, namespace):
+        parser.add_argument("id", help="start the specified story", nargs='?',
+                type=int)
+        parser.add_argument("-m", "--mywork", action="store_true",
+                help="only start stories owned by you")
+        super(StartCommand, self).__init__(parser, namespace)
+
+    def execute(self):
+        """Execute this start command.
+        """
+        if self.story:
+            puts("Story: {0}".format(self.story.name))
+
+            if not self.story.owners:
+                self.story = self.pt.set_story(self.project, self.story,
+                        self.story.state, self.owner)
+
+            # Verify that owner got the story.
+            if self.owner in self.story.owners:
+                branch = super(StartCommand, self).execute()
+                self.git.set_configuration("branch", branch,
+                        story=self.story.id)
+                self.pt.set_story(self.project, self.story,
+                        Story.STATE_STARTED)
+            else:
+                exit("Unable to update story owners.")
+        else:
+            if self.namespace.id and self.namespace.exclusive:
+                exit("No estimated story #{0} found assigned to you.".format(
+                    self.namespace.id))
+            elif self.namespace.id:
+                exit("No estimated story #{0} found in the backlog.".format(
+                    self.namespace.id))
+            elif self.namespace.exclusive:
+                exit("No estimated stories found in my work.")
+            else:
+                exit("No estimated stories found in the backlog.")
+
+    def exit(self):
+        """Handle start command exit.
+        """
+        puts("Aborted story branch.")
+        super(StartCommand, self).exit()
+
+    @cached_property
+    def story(self):
+        """Target story accessor.
+        """
+        story_id = self.namespace.id
+        exclusive = self.namespace.exclusive
+
+        if story_id and exclusive:
+            puts("Retrieving story #{0} from Pivotal Tracker for {1}...".
+                format(story_id, self.owner))
+            filter = "id:{0} owner:{1} state:unstarted,rejected -estimate:-1".\
+                format(story_id, self.owner)
+        elif story_id:
+            puts("Retrieving story #{0} from Pivotal Tracker...".format(
+                story_id))
+            filter = "id:{0} state:unstarted,rejected -estimate:-1".\
+                format(story_id)
+        elif exclusive:
+            puts("Retrieving next story from Pivotal Tracker for {0}...".
+                format(self.owner))
+            filter = "owner:{0} state:unstarted,rejected -estimate:-1".\
+                format(self.owner)
+        else:
+            filter = None
+
+        if filter:
+            ret_val = self.pt.get_story(self.project, filter)
+        else:
+            puts("Retrieving next available story from Pivotal Tracker...")
+            stories = self.pt.get_backlog(self.project)
+            types = (Story.TYPE_FEATURE, Story.TYPE_BUG, Story.TYPE_CHORE)
+            states = (Story.STATE_UNSTARTED, Story.STATE_REJECTED)
+
+            for story in stories:
+                if story.type in types and story.state in states and \
+                        (not story.owners or self.owner in story.owners):
+                    if story.type != Story.TYPE_FEATURE or story.estimate:
+                        ret_val = story
+                        break
+            else:
+                ret_val = None
+
+        return ret_val
+
+
 class StoryCommand(PivotalTrackerCommand):
     """Display story branch information.
 
@@ -199,7 +315,9 @@ class StoryCommand(PivotalTrackerCommand):
         puts(colored.white(self.story.url))
 
         if self.namespace.comments:
-            for comment in self.story.comments:
+            comments = self.pt.get_comments(self.project, self.story)
+
+            for comment in comments:
                 puts()
                 puts(colored.yellow("{0} ({1})".format(comment.author,
                     comment.created)))
@@ -207,100 +325,6 @@ class StoryCommand(PivotalTrackerCommand):
                 puts(comment.text)
 
 
-class StartCommand(BaseStartCommand, PivotalTrackerCommand):
-    """Start a branch linked to a story.
-
-    :param parser: Command-line argument parser.
-    :param namespace: Command-line argument namespace.
-    """
-
-    def __init__(self, parser, namespace):
-        parser.add_argument("id", help="start the specified story", nargs='?',
-                type=int)
-        parser.add_argument("-m", "--mywork", action="store_true",
-                help="only start stories owned by you")
-        super(StartCommand, self).__init__(parser, namespace)
-
-    def execute(self):
-        """Execute this start command.
-        """
-        if self.story:
-            puts("Story: {0}".format(self.story.name))
-            owner = self.get_value("pivotal", "owner")
-
-            if self.story.owner is None:
-                self.story = self.pt.set_story(self.project, self.story,
-                        self.story.state, owner)
-
-            # Verify that owner got the story.
-            if self.story.owner == owner:
-                branch = super(StartCommand, self).execute()
-                self.git.set_configuration("branch", branch,
-                        story=self.story.id)
-                self.pt.set_story(self.project, self.story,
-                        Story.STATE_STARTED)
-            else:
-                exit("Unable to update story owner.")
-        else:
-            if self.namespace.id and self.namespace.exclusive:
-                exit("No estimated story #{0} found assigned to you.".format(
-                    self.namespace.id))
-            elif self.namespace.id:
-                exit("No estimated story #{0} found in the backlog.".format(
-                    self.namespace.id))
-            elif self.namespace.exclusive:
-                exit("No estimated stories found in my work.")
-            else:
-                exit("No estimated stories found in the backlog.")
-
-    def exit(self):
-        """Handle start command exit.
-        """
-        puts("Aborted story branch.")
-        super(StartCommand, self).exit()
-
-    @cached_property
-    def story(self):
-        """Target story accessor.
-        """
-        story_id = self.namespace.id
-        exclusive = self.namespace.exclusive
-        owner = self.get_value("pivotal", "owner")
-
-        if story_id and exclusive:
-            puts("Retrieving story #{0} from Pivotal Tracker for {1}...".
-                format(story_id, owner))
-            filter = "id:{0} owner:{1} state:unstarted,rejected".format(
-                story_id, owner)
-        elif story_id:
-            puts("Retrieving story #{0} from Pivotal Tracker...".format(
-                story_id))
-            filter = "id:{0} state:unstarted,rejected".format(story_id)
-        elif exclusive:
-            puts("Retrieving next story from Pivotal Tracker for {0}...".
-                format(owner))
-            filter = "owner:{0} state:unstarted,rejected".format(owner)
-        else:
-            filter = None
-
-        if filter:
-            ret_val = self.pt.get_story(self.project, filter)
-        else:
-            puts("Retrieving next available story from Pivotal Tracker...")
-            stories = self.pt.get_backlog(self.project)
-
-            for story in stories:
-                if story.type in (Story.TYPE_FEATURE, Story.TYPE_BUG,
-                        Story.TYPE_CHORE) and (story.owner is None or
-                        story.owner == owner):
-                    ret_val = story
-                    break
-            else:
-                ret_val = None
-
-        return ret_val
-
-
 class TasksCommand(BaseTasksCommand, PivotalTrackerCommand):
     """List and manage story tasks.
     """
